@@ -87,6 +87,10 @@ my @cpp_rename = (
 "ext/vstring_fwd.h:vstr_fwd.h",
 "ext/vstring_util.h:vstr_util.h",
 
+"parallel/for_each_selectors.h:foreachselector.h",
+"parallel/omp_loop_static.h:omploopstatic.h",
+"parallel/multiway_mergesort.h:multiway_mergesort.h2",
+
 "profile/impl/profiler.h:_profiler.h",
 "profile/impl/profiler_algos.h:_profalgos.h",
 "profile/impl/profiler_container_size.h:_profcts.h1",
@@ -425,7 +429,7 @@ sub c_inc_rename_proc
                 $d1 = $d1 eq "" ? $1 : "$d1/$1";
                 $d2 = $2;
             }
-             else
+            else
             {
                 $d1 = $d1 eq "" ? $d2 : "$d1/$d2";
                 $d2 = "";
@@ -670,7 +674,7 @@ sub mk_manifest
     my @gforfiles = (
         'bin/gfortran\.exe', 'info/gfortran.info',
         '/libgf', '/f951\.exe', 'manifest/gfor',
-	'/libcaf_single.(?:a|la)',
+	'/libcaf_single.a',
         '/cat1/gfortran'
     );
 
@@ -694,11 +698,12 @@ sub mk_manifest
         '/include/header.gcc$',
         '/include-fixed/(?:limits|syslimits|wchar)\.h$',
         '/include-fixed/readme$',
-        '/include/(?:abm|fma4|ia32|lwp|popcnt|xop)intrin.h$',
+        '/include/(?:abm|fma4|ia32|lwp|popcnt|xop|xtest)intrin.h$',
+	'/include/(?:adx|fxsr|prfchw|rdseed|rtm|xsave|xsaveopt)intrin.h$',
         '/include/cross-stdarg.h$',
         '/include/stdint(?:|-gcc).h$',
         '/install-tools/', '/libgcc\.a', '/libgcov\.a', '/libssp*',
-        '/libquadmath.(?:a|la)',
+        '/libquadmath.a',
         '/cc1\.exe',
         '/collect2\.exe',
         '/lto-wrapper.exe',
